```{include} ../README.md

```

```{toctree}
:maxdepth: 1
:hidden:
fluids.ipynb
flow.ipynb
oil_flow.ipynb
forecast.ipynb
forecast_varying.ipynb
autoapi/index
contributing.md
conduct.md
background.md
changelog.md
```
